@@ -1,4 +1,4 @@
-__version__ = "1.1.13"
+__version__ = "1.1.17"
 
 import kappadata.caching
 import kappadata.common
@@ -17,12 +17,12 @@ from .collators.base.kd_compose_collator import KDComposeCollator
 from .collators.base.kd_single_collator import KDSingleCollator
 from .collators.kd_mix_collator import KDMixCollator
 from .collators.pad_sequences_collator import PadSequencesCollator
+from .common.transforms.norm.kd_cifar100_norm import KDCifar100Norm
 # common
 from .common.transforms.norm.kd_cifar10_norm import KDCifar10Norm
-from .common.transforms.norm.kd_cifar100_norm import KDCifar100Norm
 from .common.transforms.norm.kd_image_net_norm import KDImageNetNorm
 from .common.wrappers import (
-    BYOLMultiViewWrapper,
+    ByolMultiViewWrapper,
     ImagenetMinaugMultiViewWrapper,
     ImagenetMinaugXTransformWrapper,
     ImagenetNoaugXTransformWrapper,
@@ -40,11 +40,11 @@ from .datasets.kd_subset import KDSubset
 from .datasets.kd_wrapper import KDWrapper
 # factory
 from .factory import object_to_transform
-# samplers
-from .samplers.interleaved_sampler import InterleavedSampler, InterleavedSamplerConfig
 # samplers.batch_samplers
 from .samplers.batch_samplers import InfiniteBatchSampler
 from .samplers.batch_samplers import InterleavedBatchSampler
+# samplers
+from .samplers.interleaved_sampler import InterleavedSampler, InterleavedSamplerConfig
 # transforms base
 from .transforms.base import KDComposeTransform
 from .transforms.base import KDIdentityTransform
@@ -66,6 +66,7 @@ from .transforms.kd_random_grayscale import KDRandomGrayscale
 from .transforms.kd_random_horizontal_flip import KDRandomHorizontalFlip
 from .transforms.kd_random_resized_crop import KDRandomResizedCrop
 from .transforms.kd_random_solarize import KDRandomSolarize
+from .transforms.kd_rearrange import KDRearrange
 from .transforms.kd_resize import KDResize
 # transforms norm
 from .transforms.norm.kd_image_norm import KDImageNorm
@@ -75,6 +76,8 @@ from .transforms.patchwise_random_rotation import PatchwiseRandomRotation
 from .transforms.patchwise_shuffle import PatchwiseShuffle
 from .transforms.save_state_to_context_transform import SaveStateToContextTransform
 from .transforms.unpatchify_image import UnpatchifyImage
+from .utils.color_histogram import color_histogram
+from .utils.multi_crop_utils import SplitForwardModule
 # utils
 from .utils.transform_utils import (
     flatten_transform,
@@ -82,8 +85,6 @@ from .utils.transform_utils import (
     get_norm_transform,
     get_x_transform,
 )
-from .utils.color_histogram import color_histogram
-from .utils.multi_crop_utils import SplitForwardModule
 # wrappers.dataset_wrappers
 from .wrappers.dataset_wrappers.class_filter_wrapper import ClassFilterWrapper
 from .wrappers.dataset_wrappers.classwise_subset_wrapper import ClasswiseSubsetWrapper
